@@ -5,8 +5,7 @@
 #' waits for a return in the console before plotting the next spectrum.  Use
 #' \code{ESC} to get out of the loop.
 #' 
-#' 
-#' @param Spectra An object of S3 class \code{\link{Spectra}}.
+#' @param spectra An object of S3 class \code{\link{Spectra}}.
 #' 
 #' @param \dots Parameters to be passed downstream.
 #' 
@@ -14,33 +13,30 @@
 #' 
 #' @author Bryan A. Hanson, DePauw University.
 #' 
-#' @references \url{https://github.com/bryanhanson/ChemoSpec}
-#' 
 #' @keywords hplot
 #' 
-#' @examples
-#' 
-#' \dontrun{
+#' @seealso Additional documentation at \url{https://bryanhanson.github.io/ChemoSpec/}
 #'
-#' data(metMUD1)
-#' loopThruSpectra(metMUD1)
-#' }
-#' 
 #' @export loopThruSpectra
 #' 
 #' @importFrom grDevices devAskNewPage 
 #' 
-loopThruSpectra <- function(Spectra, ...) {
+#' @examples
+#' 
+#' \dontrun{
+#' data(metMUD1)
+#' loopThruSpectra(metMUD1)
+#' }
+#' 
+loopThruSpectra <- function(spectra, ...) {
 
-# Function to loop through a series of spectra
-# in a Spectra object for one at a time inspection
-# Bryan Hanson, DePauw Univ. Oct. 2011
-
-	cat("Type ESC to stop looping through the spectra\n\n")
-	nr <- nrow(Spectra$data)
-	for (n in 1:nr) {
-		tt <- paste("Spectrum #", n, " of ", nr, sep = "")
-		plotSpectra(Spectra, which = n, main = tt, ...)
+	.chkArgs(mode = 11L)
+	
+	cat("Press ESC to stop looping through the spectra\n\n")
+	ns <- length(spectra$names)
+	for (i in 1:ns) {
+		tt <- paste(spectra$names[i], "(#", i, " of ", ns, ")", sep = "")
+		plotSpectra(spectra, which = i, main = tt, ...)
 		devAskNewPage(ask = TRUE)
 		}
 	devAskNewPage(ask = FALSE)
